@@ -3,10 +3,10 @@ import hildon
 import osmgpsmap
 import gobject
 import os
-import evolution
-import base64
 
 
+from h_UI_selectContact import *
+
 class DetailsWindow(hildon.StackableWindow):
 
     def __init__(self, osmMapa, point, config):
@@ -19,8 +19,13 @@ class DetailsWindow(hildon.StackableWindow):
 
         self.osmMapa.set_autorotate_for_object(self)
 
+        self.menu = None
+        self.address = ""
+        
         tlldbox = gtk.VBox()
 
+        self.download_geonams = 0
+
         if len(point) == 2:
             print "point only LL use geonames to build it"
             ll = point
@@ -32,11 +37,12 @@ class DetailsWindow(hildon.StackableWindow):
                      gtk.gdk.pixbuf_new_from_file("./maps/ico_igla_32_32.png"),
                      None,
                      7  ]
-            p = self.osmMapa.get_plugin("Google - geonames")
-            if p:
-                p.ref_dawnload( ll[0], ll[1])
-                self.geonames_downloader_loop(p, tlldbox, ll[0],ll[1])
+            
+            
 
+        
+        
+        
 
 
         self.details_share = ""
@@ -77,6 +83,7 @@ class DetailsWindow(hildon.StackableWindow):
                             ref_downloader = plugin[0]
                             ref_downloader.get_reference( d['reference'] )
                             self.ref_downloader_loop(ref_downloader, tlldbox, point)
+                            self.download_geonams = 1
                             break
             except:
                 pass
@@ -92,6 +99,9 @@ class DetailsWindow(hildon.StackableWindow):
             if point[7]['address']:
                 tlldbox.pack_start( self.get_label("Addres: <small>%s</small>" % point[7]['address']), False)
                 self.details_share = "%s %s" % ( point[7]['address'], self.details_share )
+                self.address = point[7]['address']
+                
+                
         except Exception, e:
                 print "add reference error [7] address",e
         try:
@@ -172,14 +182,40 @@ class DetailsWindow(hildon.StackableWindow):
         self.vbox.pack_start(vbox0, True)
 
 
-
+        self.build_menu()
 
         self.show_all()
 
+        p = self.osmMapa.get_plugin("Google - geonames")
+        if p and self.download_geonams == 0 and self.address == "":
+            p.ref_dawnload( point[0], point[1])
+            self.download_geonams = 1
+            self.geonames_downloader_loop(p, tlldbox, point[0],point[1])
 
 
         #self.run()
         #self.destroy()
+        
+    def build_menu(self):
+        if self.menu == None:
+            self.menu = hildon.AppMenu()
+            self.set_app_menu(self.menu)
+            
+        add = 0
+        if self.address:
+            add = 1
+            m_add_atc = gtk.Button("Add address to contact")
+            m_add_atc.connect("clicked", self.on_m_add_atc, self.address)
+            self.menu.append(m_add_atc)
+            
+        
+        if add:
+            print "add address menu "
+            self.menu.show_all()
+    def on_m_add_atc(self, w,address):
+        print "-- add address to contact start --[%s]" %address
+        sc = SelectContact( self.osmMapa, None, "add address", address )
+        sc.start_dialog()
 
     def geonames_downloader_loop(self,ref_downloader, tlldbox, lat,lon):
         if ref_downloader.ref_result == []:
@@ -188,6 +224,8 @@ class DetailsWindow(hildon.StackableWindow):
             try:
                 tlldbox.pack_start( self.get_label("Addres: <small>%s</small>" % ref_downloader.ref_result[1]), False)
                 self.details_share = "%s %s" % ( ref_downloader.ref_result[1], self.details_share )
+                self.address = ref_downloader.ref_result[1]
+                self.build_menu()
                 tlldbox.show_all()
             except Exception, e:
                 print "add reference error",e
@@ -198,7 +236,8 @@ class DetailsWindow(hildon.StackableWindow):
         else:
             try:
                 tlldbox.pack_start( self.get_label("Addres: <small>%s</small>" % ref_downloader.ref_result[1]), False)
-
+                self.address = ref_downloader.ref_result[1]
+                self.build_menu()
                 hbox = gtk.HBox()
                 l = gtk.Label("Phone: ")
                 hbox.pack_start(l, False)
@@ -235,36 +274,14 @@ class DetailsWindow(hildon.StackableWindow):
 
     def on_bt_addContact(self,w, store, point):
         print "--- add concat --- "
-        addresses = evolution.ebook.open_addressbook('default')
-        img = ""
-        try:
-            i = point[4]
-            i.save( "/tmp/.yosm_pix.png", "png" )
-            f = open("/tmp/.yosm_pix.png","r")
-            l = f.read()
-            base_img = base64.encodestring(l)
-
-
-
-            img = """PHOTO;TYPE=PNG;ENCODING=BASE64:
-    """+base_img.replace("\n","\n\t")+"""
-
-"""
-        except:
-            pass
-
-        vcard = """BEGIN:VCARD
-VERSION:3.0
-FN:"""+store[0]+"""
-TEL;TYPE=CELL:"""+store[2].replace(" ","")+"""
-NOTE:add by yosmapa
-ADR:;"""+store[1].replace("  "," ")+""";;;;;
-"""+img+"""END:VCARD"""
-        print "---- vcard ---\n",vcard,"\n-----------vcard------"
-
-        c = evolution.ebook.EContact(vcard)
-        addresses.add_contact(c)
-        self.osmMapa.showBanner("Contact added.")
+        sc = SelectContact()
+        sc.add_new_concat(
+                          store[0],
+                          store[2],
+                          store[1],
+                          point[4]
+                          )
+        
         print "--- add concat DONE --- "
 
     def on_route_to_it(self, w, lat, lon):
