@@ -62,7 +62,7 @@ gtk.gdk.threads_init()
 
 
 name = "yosmapa"
-version = "0.19-19"
+version = "0.19-20"
 
 
 
@@ -421,6 +421,8 @@ class UI(hildon.StackableWindow):
             self.fullscreen()
             self.window_is_fullscreen = True
 
+    def get_home(self):
+        return home
     def get_config(self):
         return CONFIG
     def set_config(self,str, val):
@@ -621,8 +623,8 @@ class UI(hildon.StackableWindow):
 
         self.window_rotate = -1
         self.set_autorotate_for_object(self)
-
-
+        
+        
         try:
             self.osm.set_center_and_zoom( CONFIG['lat'], CONFIG['lon'], CONFIG['zoom'] )
         except:
@@ -1085,7 +1087,8 @@ class UI(hildon.StackableWindow):
     def map_release_menu(self, xR, yR ):
         t = time.time()
 
-        if xR == self.cliked_at_xyt[0] and yR == self.cliked_at_xyt[1] and (t-0.5) > self.cliked_at_xyt[2]:
+        accuracy = 10
+        if int(xR/accuracy) == int(self.cliked_at_xyt[0]/accuracy) and int(yR/accuracy) == int(self.cliked_at_xyt[1]/accuracy) and (t-0.5) > self.cliked_at_xyt[2]:
             print "menu tab map show !"
 
             m = gtk.Menu()
